@@ -42,13 +42,13 @@ class CalibrationConstantVersionApi(Base):
             condition,
             karabo_da='',
             event_at=None,
-            snapshot_at=None):
+            pdu_snapshot_at=None):
         api_url = self.__get_api_url('get_by_detector_conditions')
         params = {'detector_identifier': detector_identifier,
                   'calibration_id': str(calibration_id),
                   'karabo_da': karabo_da,
                   'event_at': event_at,
-                  'snapshot_at': snapshot_at}
+                  'pdu_snapshot_at': pdu_snapshot_at}
 
         return self.api_get(api_url,
                             params=params,
