@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class DetectorApi(Base):
@@ -22,9 +23,13 @@ class DetectorApi(Base):
         api_url = self.__get_api_url(parameter_id)
         return self.api_get(api_url, params={})
 
-    def get_all_detectors_by_name_api(self, name):
+    def get_all_detectors_by_name_api(self, name,
+                                      page=DEF_PAGE,
+                                      page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'name': name})
+        return self.api_get(api_url, params={'name': name,
+                                             'page': page,
+                                             'page_size': page_size})
 
     def get_all_detectors_by_identifier_api(self, identifier):
         api_url = self.__get_api_url()
