@@ -52,12 +52,12 @@ class PhysicalDetectorUnitApi(Base):
                                              'page_size': page_size})
 
     #
-    def get_all_by_detector_api(self, detector_id, snapshot_at):
+    def get_all_by_detector_api(self, detector_id, pdu_snapshot_at):
         api_action_name = '/get_all_by_detector'
         api_url = self.__get_api_url(api_action_name)
 
         params = {'detector_id': str(detector_id),
-                  'snapshot_at': snapshot_at}
+                  'pdu_snapshot_at': pdu_snapshot_at}
 
         return self.api_get(api_url, params=params)
 
