@@ -357,10 +357,14 @@ class CalibrationClient(CalibrationApi,
         logging.debug('* det_retrieve_h == {0}'.format(det_retrieve_h))
 
         det_identifier = det_retrieve_h['detector_identifier']
-        snapshot_at = Util.get_opt_hash_val(det_retrieve_h, 'snapshot_at')
+        pdu_snapshot_at = Util.get_opt_hash_val(det_retrieve_h, 'pdu_snapshot_at')
+
+        # accepts legacy parameter name (snapshot_at)
+        if pdu_snapshot_at == '':
+            pdu_snapshot_at = Util.get_opt_hash_val(det_retrieve_h, 'snapshot_at')
 
         resp = self.get_all_phy_det_units_from_detector_int(det_identifier,
-                                                            snapshot_at)
+                                                            pdu_snapshot_at)
 
         if not resp['success']:
             error_msg = '{0} >> {1}'.format(resp['info'], resp['app_info'])
@@ -370,12 +374,12 @@ class CalibrationClient(CalibrationApi,
         return resp
 
     def get_all_phy_det_units_from_detector_int(self, detector_identifier,
-                                                snapshot_at):
+                                                pdu_snapshot_at):
         #
         # Get detector_id from detector_identifier
         #
         logging.debug('* det_identifier == {0}'.format(detector_identifier))
-        logging.debug('* snapshot_at == {0}'.format(snapshot_at))
+        logging.debug('* pdu_snapshot_at == {0}'.format(pdu_snapshot_at))
 
         resp = Detector.get_by_identifier(self, detector_identifier)
         if resp['success']:
@@ -390,7 +394,7 @@ class CalibrationClient(CalibrationApi,
 
         # get_all_by_detector
         resp = PhysicalDetectorUnit.get_all_by_detector(self, detector_id,
-                                                        snapshot_at)
+                                                        pdu_snapshot_at)
         if resp['success']:
             all_phy_det_units = resp['data']
 
@@ -897,7 +901,7 @@ class CalibrationClient(CalibrationApi,
         # Update calibration_constant_version
         # set parameters from DB
         ccv_pars = {k: v for k, v in ccv.items() if
-                    (not isinstance(v, dict) and k != 'id')}
+                    (not isinstance(v, dict) and k != 'id' and k!= 'created_at')}
         ccv_pars['calibration_constant_id'] = ccv['calibration_constant']['id']
         ccv_pars['physical_detector_unit_id'] = ccv['physical_detector_unit'][
             'id']
