@@ -210,10 +210,10 @@ class CalibrationConstantVersion:
                                                    condition,
                                                    karabo_da='',
                                                    event_at=None,
-                                                   snapshot_at=None):
+                                                   pdu_snapshot_at=None):
         resp = cal_client.get_calibration_constant_versions_by_detector_conditions_api(  # noqa
             detector_identifier, calibration_id, condition, karabo_da,
-            event_at, snapshot_at
+            event_at, pdu_snapshot_at
         )
 
         msg = 'ccv >> get_calibration_constant_versions_by_detector_conditions_api'  # noqa
