@@ -10,7 +10,7 @@ MODULE_NAME = PARAMETER
 
 class Parameter:
     def __init__(self, calibration_client,
-                 name, unit_id, flg_available, flg_logarithmic,
+                 name, unit_id, flg_available, flg_logarithmic, flg_text,
                  def_lower_deviation_value, def_upper_deviation_value,
                  description=''):
         self.calibration_client = calibration_client
@@ -19,6 +19,7 @@ class Parameter:
         self.unit_id = unit_id
         self.flg_available = flg_available
         self.flg_logarithmic = flg_logarithmic
+        self.flg_text = flg_text
         self.def_lower_deviation_value = def_lower_deviation_value
         self.def_upper_deviation_value = def_upper_deviation_value
         self.description = description
@@ -94,6 +95,7 @@ class Parameter:
                 'unit_id': self.unit_id,
                 'flg_available': self.flg_available,
                 'flg_logarithmic': self.flg_logarithmic,
+                'flg_text': self.flg_text,
                 'def_lower_deviation_value': self.def_lower_deviation_value,
                 'def_upper_deviation_value': self.def_upper_deviation_value,
                 'description': self.description
