@@ -17,6 +17,11 @@ class ApiBase(unittest.TestCase):
 
         return self.load_response_content(response)
 
+    def get_and_validate_set_entry(self, response):
+        assert response.status_code in [HTTPStatus.CREATED, HTTPStatus.OK]
+
+        return self.load_response_content(response)
+
     def get_and_validate_all_entries_by_name(self, response):
         assert response.status_code == HTTPStatus.OK
 
