@@ -20,6 +20,7 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
                 'unit_id': -1,
                 'flg_available': True,
                 'flg_logarithmic': False,
+                'flg_text': False,
                 'def_lower_deviation_value': 1.0,
                 'def_upper_deviation_value': 1.2,
                 'description': 'desc 01'
@@ -60,6 +61,7 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
         assert receive['unit_id'] == expect['unit_id']
         assert receive['flg_available'] == expect['flg_available']
         assert receive['flg_logarithmic'] == expect['flg_logarithmic']
+        assert receive['flg_text'] == expect['flg_text']
         assert receive['def_lower_deviation_value'] \
                == expect['def_lower_deviation_value']
         assert receive['def_upper_deviation_value'] \
@@ -83,10 +85,9 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
 
     def __update_entry_api(self, entry_id, expect):
         unique_name_upd = generate_unique_name('ParameterApiUpd')
+        # name, unit_id and flg_text cannot be updated
         parameter_upd = {
             PARAMETER: {
-                'name': expect['name'],
-                # 'unit_id': '-1',
                 'flg_available': False,
                 'flg_logarithmic': True,
                 'def_lower_deviation_value': 0.0,
@@ -98,8 +99,11 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
         res = self.cal_client.update_parameter_api(entry_id, parameter_upd)
         receive = self.load_response_content(res)
 
-        # Add parameters not send to the update API
+        # Add parameters not sent to the update API
         parameter_upd[PARAMETER]['unit_id'] = -1
+        parameter_upd[PARAMETER]['name'] = expect['name']
+        parameter_upd[PARAMETER]['flg_text'] = expect['flg_text']
+
         expect_upd = parameter_upd[PARAMETER]
 
         self.fields_validation(receive, expect_upd)
