@@ -6,6 +6,7 @@ from http import HTTPStatus
 import pytest
 
 from .api_base import ApiBase
+from ..common.config_test import *
 
 
 @pytest.mark.usefixtures('client_cls')
@@ -39,9 +40,12 @@ class ReportApiTest(ApiBase, unittest.TestCase):
             # Check that expected creation result was received
             self.fields_validation(created_entry_received, expect)
 
-            # Create duplicated entry
+            # Create duplicated entry (should throw an error)
+            self.__create_error_entry_uk_api(report)
+
+            # Set duplicated entry
             # (should NOT throw an error and return the report from the DB)
-            self.__create_failsafe_duplicate_entry_uk_api(report, expect)
+            self.__set_failsafe_duplicate_entry_uk_api(report, expect)
 
             # Get entry by name
             self.__get_all_entries_by_name_api(repo_name, expect)
@@ -81,9 +85,17 @@ class ReportApiTest(ApiBase, unittest.TestCase):
         self.fields_validation(receive, expect)
         return receive
 
-    def __create_failsafe_duplicate_entry_uk_api(self, entry_info, expect):
+    def __create_error_entry_uk_api(self, entry_info):
         response = self.cal_client.create_report_api(entry_info)
-        receive = self.get_and_validate_create_entry(response)
+        receive = self.load_response_content(response)
+        expect = {'info': {'name': ['has already been taken'],
+                           'file_path': ['has already been taken']}}
+        assert receive == expect
+        assert response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY
+
+    def __set_failsafe_duplicate_entry_uk_api(self, entry_info, expect):
+        response = self.cal_client.set_report_api(entry_info)
+        receive = self.get_and_validate_set_entry(response)
         self.fields_validation(receive, expect)
 
     def __update_entry_api(self, entry_id, expect):
@@ -111,8 +123,9 @@ class ReportApiTest(ApiBase, unittest.TestCase):
         assert expect['flg_available'] != expect_upd['flg_available']
         assert expect['description'] != expect_upd['description']
 
-    def __get_all_entries_by_name_api(self, name, expect):
-        response = self.cal_client.get_all_reports_by_name_api(name)
+    def __get_all_entries_by_name_api(self, name, expect,
+                                      page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        response = self.cal_client.get_all_reports_by_name_api(name, page, page_size)
         receive = self.get_and_validate_all_entries_by_name(response)
         self.fields_validation(receive, expect)
 
