@@ -65,6 +65,39 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             'description': 'desc version 01 Updated!'
         }
 
+        self.expected_db_01 = {
+            'id': -1,
+            'name': 'CALIBRATION_CONSTANT_VERSION_TEST-1_DO_NOT_DELETE',
+            'file_name': 'cal.r0001.c0002.h5',
+            'path_to_file': '/usr/local/cal_repo/',
+            'data_set_name': 'exp001.cal001',
+            'flg_deployed': True,
+            'flg_good_quality': True,
+            'begin_validity_at': '2014-05-20T10:30:14.000+02:00',
+            'end_validity_at': '2029-06-24T00:00:00.000+02:00',
+            'begin_at': '2014-05-20T12:00:00.000+02:00',
+            'start_idx': None,
+            'end_idx': None,
+            'raw_data_location': None,
+            'description': None,
+            # 'calibration_constant': {
+            #     'id': -1,
+            #     'name': 'CALIBRATION_CONSTANT_TEST-1_DO_NOT_DELETE',
+            #     'flg_auto_approve': True,
+            #     'flg_available': True,
+            #     'description': 'Created automatically via seed:seed_tests',
+            #     'detector_type_id': -1,
+            #     'calibration_id': -1,
+            #     'condition_id': -1},
+            'calibration_constant_id': -1,
+            # 'physical_detector_unit': {
+            #     'id': -1,
+            #     'name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+            #     'detector_type_id': -1,
+            #     'flg_available': True,
+            #     'description': 'Created automatically via seed:seed_tests'}
+            'physical_detector_unit_id': -1}
+
         self.expected_db_02 = {
             'id': -2,
             'name': 'CALIBRATION_CONSTANT_VERSION_TEST-2_DO_NOT_DELETE',
@@ -367,7 +400,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         #
         calibration_constant_ids = [-1, -2]
         physical_detector_unit_id = -1
-        event_at = '2014-05-26T12:00:00.000+02:00'
+        event_at = '2014-05-24T12:00:00.000+02:00'
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_closest_by_time(
@@ -413,6 +446,22 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
 
         self.assert_find_success(MODULE_NAME, result1, self.expected_db_02)
 
+    def test_calibration_constants_get_prior_in_time(self):
+        #
+        # Search for the valid version among many
+        #
+        calibration_constant_ids = [-1, -2, -3, -4]
+        physical_detector_unit_id = -1
+        event_at = '2014-05-26T09:00:00.000+02:00'
+        snapshot_at = None
+
+        result1 = CalibrationConstantVersion.get_prior_in_time(
+            self.cal_client, calibration_constant_ids,
+            physical_detector_unit_id,
+            event_at, snapshot_at)
+
+        self.assert_find_success(MODULE_NAME, result1, self.expected_db_01)
+
     def test_calibration_constants_get_all_versions_now(self):
         #
         # Search for all the version
